"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .distinguishedname import DistinguishedName, DistinguishedNameTypedDict
from .edipartyname import EdiPartyName, EdiPartyNameTypedDict
from .generalsubtreeip import GeneralSubtreeIP, GeneralSubtreeIPTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class NameConstraintsTypedDict(TypedDict):
    critical: NotRequired[bool]
    excluded_directory_names: NotRequired[Nullable[List[DistinguishedNameTypedDict]]]
    r"""A record providing excluded names of the type directoryName in leaf certificates whose trust path includes this certificate."""
    excluded_edi_party_names: NotRequired[Nullable[List[EdiPartyNameTypedDict]]]
    r"""A record providing excluded names of the type ediPartyName in leaf certificates whose trust path includes this certificate."""
    excluded_email_addresses: NotRequired[Nullable[List[str]]]
    r"""A record providing a range of excluded names of the type rfc822Name in leaf certificates whose trust path includes this certificate."""
    excluded_ip_addresses: NotRequired[Nullable[List[GeneralSubtreeIPTypedDict]]]
    r"""A record providing a range of excluded names of the type iPAddress in leaf certificates whose trust path includes this certificate."""
    excluded_names: NotRequired[Nullable[List[str]]]
    r"""A record providing a range of excluded names of the type dNSName in leaf certificates whose trust path includes this certificate."""
    excluded_registered_ids: NotRequired[Nullable[List[str]]]
    r"""A record providing excluded names of the type registeredID in leaf certificates whose trust path includes this certificate."""
    excluded_uris: NotRequired[Nullable[List[str]]]
    r"""A record providing a range of excluded uniform resource identifiers in leaf certificates whose trust path includes this certificate."""
    permitted_directory_names: NotRequired[Nullable[List[DistinguishedNameTypedDict]]]
    r"""A record providing permitted names of the type directoryName in leaf certificates whose trust path includes this certificate."""
    permitted_edi_party_names: NotRequired[Nullable[List[EdiPartyNameTypedDict]]]
    r"""A record providing permitted names of the type ediPartyName in leaf certificates whose trust path includes this certificate."""
    permitted_email_addresses: NotRequired[Nullable[List[str]]]
    r"""A record providing a range of permitted names of the type rfc822Name in leaf certificates whose trust path includes this certificate."""
    permitted_ip_addresses: NotRequired[Nullable[List[GeneralSubtreeIPTypedDict]]]
    r"""A record providing a range of permitted names of the type iPAddress in leaf certificates whose trust path includes this certificate."""
    permitted_names: NotRequired[Nullable[List[str]]]
    r"""A record providing a range of permitted names of the type dNSName in leaf certificates whose trust path includes this certificate."""
    permitted_registered_ids: NotRequired[Nullable[List[str]]]
    r"""A record providing permitted names of the type registeredID in leaf certificates whose trust path includes this certificate."""
    permitted_uris: NotRequired[Nullable[List[str]]]
    r"""A record providing a range of permitted uniform resource identifiers in leaf certificates whose trust path includes this certificate."""


class NameConstraints(BaseModel):
    critical: Optional[bool] = None

    excluded_directory_names: OptionalNullable[List[DistinguishedName]] = UNSET
    r"""A record providing excluded names of the type directoryName in leaf certificates whose trust path includes this certificate."""

    excluded_edi_party_names: OptionalNullable[List[EdiPartyName]] = UNSET
    r"""A record providing excluded names of the type ediPartyName in leaf certificates whose trust path includes this certificate."""

    excluded_email_addresses: OptionalNullable[List[str]] = UNSET
    r"""A record providing a range of excluded names of the type rfc822Name in leaf certificates whose trust path includes this certificate."""

    excluded_ip_addresses: OptionalNullable[List[GeneralSubtreeIP]] = UNSET
    r"""A record providing a range of excluded names of the type iPAddress in leaf certificates whose trust path includes this certificate."""

    excluded_names: OptionalNullable[List[str]] = UNSET
    r"""A record providing a range of excluded names of the type dNSName in leaf certificates whose trust path includes this certificate."""

    excluded_registered_ids: OptionalNullable[List[str]] = UNSET
    r"""A record providing excluded names of the type registeredID in leaf certificates whose trust path includes this certificate."""

    excluded_uris: OptionalNullable[List[str]] = UNSET
    r"""A record providing a range of excluded uniform resource identifiers in leaf certificates whose trust path includes this certificate."""

    permitted_directory_names: OptionalNullable[List[DistinguishedName]] = UNSET
    r"""A record providing permitted names of the type directoryName in leaf certificates whose trust path includes this certificate."""

    permitted_edi_party_names: OptionalNullable[List[EdiPartyName]] = UNSET
    r"""A record providing permitted names of the type ediPartyName in leaf certificates whose trust path includes this certificate."""

    permitted_email_addresses: OptionalNullable[List[str]] = UNSET
    r"""A record providing a range of permitted names of the type rfc822Name in leaf certificates whose trust path includes this certificate."""

    permitted_ip_addresses: OptionalNullable[List[GeneralSubtreeIP]] = UNSET
    r"""A record providing a range of permitted names of the type iPAddress in leaf certificates whose trust path includes this certificate."""

    permitted_names: OptionalNullable[List[str]] = UNSET
    r"""A record providing a range of permitted names of the type dNSName in leaf certificates whose trust path includes this certificate."""

    permitted_registered_ids: OptionalNullable[List[str]] = UNSET
    r"""A record providing permitted names of the type registeredID in leaf certificates whose trust path includes this certificate."""

    permitted_uris: OptionalNullable[List[str]] = UNSET
    r"""A record providing a range of permitted uniform resource identifiers in leaf certificates whose trust path includes this certificate."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "critical",
            "excluded_directory_names",
            "excluded_edi_party_names",
            "excluded_email_addresses",
            "excluded_ip_addresses",
            "excluded_names",
            "excluded_registered_ids",
            "excluded_uris",
            "permitted_directory_names",
            "permitted_edi_party_names",
            "permitted_email_addresses",
            "permitted_ip_addresses",
            "permitted_names",
            "permitted_registered_ids",
            "permitted_uris",
        ]
        nullable_fields = [
            "excluded_directory_names",
            "excluded_edi_party_names",
            "excluded_email_addresses",
            "excluded_ip_addresses",
            "excluded_names",
            "excluded_registered_ids",
            "excluded_uris",
            "permitted_directory_names",
            "permitted_edi_party_names",
            "permitted_email_addresses",
            "permitted_ip_addresses",
            "permitted_names",
            "permitted_registered_ids",
            "permitted_uris",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .rootstore import RootStore, RootStoreTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ValidationTypedDict(TypedDict):
    apple: NotRequired[RootStoreTypedDict]
    chrome: NotRequired[RootStoreTypedDict]
    microsoft: NotRequired[RootStoreTypedDict]
    nss: NotRequired[RootStoreTypedDict]


class Validation(BaseModel):
    apple: Optional[RootStore] = None

    chrome: Optional[RootStore] = None

    microsoft: Optional[RootStore] = None

    nss: Optional[RootStore] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SapRouterClientInfoTypedDict(TypedDict):
    connected: NotRequired[bool]
    connected_on: NotRequired[str]
    id: NotRequired[int]
    routed: NotRequired[bool]
    service: NotRequired[str]
    traced: NotRequired[bool]


class SapRouterClientInfo(BaseModel):
    connected: Optional[bool] = None

    connected_on: Optional[str] = None

    id: Optional[int] = None

    routed: Optional[bool] = None

    service: Optional[str] = None

    traced: Optional[bool] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MongodbBuildInfoBuildEnvironmentTypedDict(TypedDict):
    cc: NotRequired[str]
    cc_flags: NotRequired[str]
    cxx: NotRequired[str]
    cxx_flags: NotRequired[str]
    dist_arch: NotRequired[str]
    dist_mod: NotRequired[str]
    link_flags: NotRequired[str]
    target_arch: NotRequired[str]
    target_os: NotRequired[str]


class MongodbBuildInfoBuildEnvironment(BaseModel):
    cc: Optional[str] = None

    cc_flags: Optional[str] = None

    cxx: Optional[str] = None

    cxx_flags: Optional[str] = None

    dist_arch: Optional[str] = None

    dist_mod: Optional[str] = None

    link_flags: Optional[str] = None

    target_arch: Optional[str] = None

    target_os: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DhcpdiscoverIPAddressTypedDict(TypedDict):
    default_gateway: NotRequired[str]
    dhcp_enable: NotRequired[bool]
    ip_address: NotRequired[str]
    link_local_address: NotRequired[str]
    subnetmask: NotRequired[str]


class DhcpdiscoverIPAddress(BaseModel):
    default_gateway: Optional[str] = None

    dhcp_enable: Optional[bool] = None

    ip_address: Optional[str] = None

    link_local_address: Optional[str] = None

    subnetmask: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ssh_algorithmselection import (
    SSHAlgorithmSelection,
    SSHAlgorithmSelectionTypedDict,
)
from .ssh_endpointid import SSHEndpointID, SSHEndpointIDTypedDict
from .ssh_kexinitmessage import SSHKexInitMessage, SSHKexInitMessageTypedDict
from .ssh_serverhostkey import SSHServerHostKey, SSHServerHostKeyTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SSHTypedDict(TypedDict):
    algorithm_selection: NotRequired[SSHAlgorithmSelectionTypedDict]
    endpoint_id: NotRequired[SSHEndpointIDTypedDict]
    hassh_fingerprint: NotRequired[str]
    kex_init_message: NotRequired[SSHKexInitMessageTypedDict]
    server_host_key: NotRequired[SSHServerHostKeyTypedDict]


class SSH(BaseModel):
    algorithm_selection: Optional[SSHAlgorithmSelection] = None

    endpoint_id: Optional[SSHEndpointID] = None

    hassh_fingerprint: Optional[str] = None

    kex_init_message: Optional[SSHKexInitMessage] = None

    server_host_key: Optional[SSHServerHostKey] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class AuthenticationErrorDetailTypedDict(TypedDict):
    code: NotRequired[int]
    r"""HTTP status code"""
    message: NotRequired[str]
    r"""Human-readable message describing the error occurrence"""
    reason: NotRequired[str]
    r"""Human-readable explanation of the underlying cause of the error"""
    request: NotRequired[str]
    status: NotRequired[str]
    r"""HTTP status message associated with the error"""


class AuthenticationErrorDetail(BaseModel):
    code: Optional[int] = None
    r"""HTTP status code"""

    message: Optional[str] = None
    r"""Human-readable message describing the error occurrence"""

    reason: Optional[str] = None
    r"""Human-readable explanation of the underlying cause of the error"""

    request: Optional[str] = None

    status: Optional[str] = None
    r"""HTTP status message associated with the error"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .hosttimeline import HostTimeline, HostTimelineTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeHostTimelineTypedDict(TypedDict):
    result: NotRequired[HostTimelineTypedDict]


class ResponseEnvelopeHostTimeline(BaseModel):
    result: Optional[HostTimeline] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CobaltStrikePostExTypedDict(TypedDict):
    x64: NotRequired[str]
    x86: NotRequired[str]


class CobaltStrikePostEx(BaseModel):
    x64: Optional[str] = None

    x86: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .cobaltstrike_config import CobaltStrikeConfig, CobaltStrikeConfigTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CobaltStrikeTypedDict(TypedDict):
    x64: NotRequired[CobaltStrikeConfigTypedDict]
    x86: NotRequired[CobaltStrikeConfigTypedDict]


class CobaltStrike(BaseModel):
    x64: Optional[CobaltStrikeConfig] = None

    x86: Optional[CobaltStrikeConfig] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class OllamaModelTypedDict(TypedDict):
    digest: NotRequired[str]
    expires_at: NotRequired[str]
    family: NotRequired[str]
    model: NotRequired[str]
    name: NotRequired[str]
    parent_model: NotRequired[str]
    size: NotRequired[int]
    size_vram: NotRequired[int]


class OllamaModel(BaseModel):
    digest: Optional[str] = None

    expires_at: Optional[str] = None

    family: Optional[str] = None

    model: Optional[str] = None

    name: Optional[str] = None

    parent_model: Optional[str] = None

    size: Optional[int] = None

    size_vram: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SecurityCapabilitiesTypedDict(TypedDict):
    access_policy_config: NotRequired[bool]
    default_access_policy: NotRequired[bool]
    dot1x: NotRequired[bool]
    http_digest: NotRequired[bool]
    kerberos_token: NotRequired[bool]
    max_password_length: NotRequired[int]
    max_username_length: NotRequired[int]
    max_users: NotRequired[int]
    onboard_key_generation: NotRequired[bool]
    rel_token: NotRequired[bool]
    remote_user_handling: NotRequired[bool]
    saml_token: NotRequired[bool]
    supported_eap_methods: NotRequired[int]
    tls_1_0: NotRequired[bool]
    tls_1_1: NotRequired[bool]
    tls_1_2: NotRequired[bool]
    username_token: NotRequired[bool]
    x509_token: NotRequired[bool]


class SecurityCapabilities(BaseModel):
    access_policy_config: Optional[bool] = None

    default_access_policy: Optional[bool] = None

    dot1x: Optional[bool] = None

    http_digest: Optional[bool] = None

    kerberos_token: Optional[bool] = None

    max_password_length: Optional[int] = None

    max_username_length: Optional[int] = None

    max_users: Optional[int] = None

    onboard_key_generation: Optional[bool] = None

    rel_token: Optional[bool] = None

    remote_user_handling: Optional[bool] = None

    saml_token: Optional[bool] = None

    supported_eap_methods: Optional[int] = None

    tls_1_0: Optional[bool] = None

    tls_1_1: Optional[bool] = None

    tls_1_2: Optional[bool] = None

    username_token: Optional[bool] = None

    x509_token: Optional[bool] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EthereumVersionTypedDict(TypedDict):
    client: NotRequired[str]
    compiler: NotRequired[str]
    platform: NotRequired[str]
    trailing: NotRequired[str]
    version: NotRequired[str]


class EthereumVersion(BaseModel):
    client: Optional[str] = None

    compiler: Optional[str] = None

    platform: Optional[str] = None

    trailing: Optional[str] = None

    version: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class AuthTypedDict(TypedDict):
    enabled: NotRequired[bool]


class Auth(BaseModel):
    enabled: Optional[bool] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CtRecordTypedDict(TypedDict):
    added_to_ct_at: NotRequired[str]
    r"""An RFC-3339-formatted timestamp indicating when the certificate was entered into the CT log."""
    ct_to_censys_at: NotRequired[str]
    r"""An RFC-3339-formated timestamp indicating when the certificate was ingested from the CT log into the Censys dataset."""
    index: NotRequired[int]
    r"""Numerical marker of the certificate's place in the CT log."""


class CtRecord(BaseModel):
    added_to_ct_at: Optional[str] = None
    r"""An RFC-3339-formatted timestamp indicating when the certificate was entered into the CT log."""

    ct_to_censys_at: Optional[str] = None
    r"""An RFC-3339-formated timestamp indicating when the certificate was ingested from the CT log into the Censys dataset."""

    index: Optional[int] = None
    r"""Numerical marker of the certificate's place in the CT log."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .mediaprofile import MediaProfile, MediaProfileTypedDict
from .mediastreaming import MediaStreaming, MediaStreamingTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MediaCapabilitiesTypedDict(TypedDict):
    osd: NotRequired[bool]
    profile: NotRequired[MediaProfileTypedDict]
    rotation: NotRequired[bool]
    snapshot_uri: NotRequired[bool]
    streaming: NotRequired[MediaStreamingTypedDict]
    video_source_mode: NotRequired[bool]


class MediaCapabilities(BaseModel):
    osd: Optional[bool] = None

    profile: Optional[MediaProfile] = None

    rotation: Optional[bool] = None

    snapshot_uri: Optional[bool] = None

    streaming: Optional[MediaStreaming] = None

    video_source_mode: Optional[bool] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class SSHKexInitMessageTypedDict(TypedDict):
    client_to_server_ciphers: NotRequired[Nullable[List[str]]]
    r"""A list of ssh cipher algorithm identifiers, named according to section 6 of https://www.ietf.org/rfc/rfc4251.txt; see https://www.iana.org/assignments/ssh-parameters/ssh-parameters.xhtml#ssh-parameters-16 for standard values."""
    client_to_server_compression: NotRequired[Nullable[List[str]]]
    r"""A list of ssh compression algorithm identifiers, named according to section 6 of https://www.ietf.org/rfc/rfc4251.txt; see https://www.iana.org/assignments/ssh-parameters/ssh-parameters.xhtml#ssh-parameters-20 for standard values."""
    client_to_server_languages: NotRequired[Nullable[List[str]]]
    r"""A name-list of language tags in order of preference. As Defined in https://www.ietf.org/rfc/rfc3066.txt."""
    client_to_server_macs: NotRequired[Nullable[List[str]]]
    r"""A list of ssh MAC algorithm identifiers, named according to section 6 of https://www.ietf.org/rfc/rfc4251.txt; see https://www.iana.org/assignments/ssh-parameters/ssh-parameters.xhtml#ssh-parameters-18 for standard values."""
    first_kex_follows: NotRequired[bool]
    host_key_algorithms: NotRequired[Nullable[List[str]]]
    r"""Asymmetric key algorithms for the host key supported by the client."""
    kex_algorithms: NotRequired[Nullable[List[str]]]
    r"""Key exchange algorithms used in the handshake."""
    server_to_client_ciphers: NotRequired[Nullable[List[str]]]
    r"""A list of ssh cipher algorithm identifiers, named according to section 6 of https://www.ietf.org/rfc/rfc4251.txt; see https://www.iana.org/assignments/ssh-parameters/ssh-parameters.xhtml#ssh-parameters-16 for standard values."""
    server_to_client_compression: NotRequired[Nullable[List[str]]]
    r"""A list of ssh compression algorithm identifiers, named according to section 6 of https://www.ietf.org/rfc/rfc4251.txt; see https://www.iana.org/assignments/ssh-parameters/ssh-parameters.xhtml#ssh-parameters-20 for standard values."""
    server_to_client_languages: NotRequired[Nullable[List[str]]]
    r"""A name-list of language tags in order of preference. As Defined in https://www.ietf.org/rfc/rfc3066.txt."""
    server_to_client_macs: NotRequired[Nullable[List[str]]]
    r"""A list of ssh MAC algorithm identifiers, named according to section 6 of https://www.ietf.org/rfc/rfc4251.txt; see https://www.iana.org/assignments/ssh-parameters/ssh-parameters.xhtml#ssh-parameters-18 for standard values."""


class SSHKexInitMessage(BaseModel):
    client_to_server_ciphers: OptionalNullable[List[str]] = UNSET
    r"""A list of ssh cipher algorithm identifiers, named according to section 6 of https://www.ietf.org/rfc/rfc4251.txt; see https://www.iana.org/assignments/ssh-parameters/ssh-parameters.xhtml#ssh-parameters-16 for standard values."""

    client_to_server_compression: OptionalNullable[List[str]] = UNSET
    r"""A list of ssh compression algorithm identifiers, named according to section 6 of https://www.ietf.org/rfc/rfc4251.txt; see https://www.iana.org/assignments/ssh-parameters/ssh-parameters.xhtml#ssh-parameters-20 for standard values."""

    client_to_server_languages: OptionalNullable[List[str]] = UNSET
    r"""A name-list of language tags in order of preference. As Defined in https://www.ietf.org/rfc/rfc3066.txt."""

    client_to_server_macs: OptionalNullable[List[str]] = UNSET
    r"""A list of ssh MAC algorithm identifiers, named according to section 6 of https://www.ietf.org/rfc/rfc4251.txt; see https://www.iana.org/assignments/ssh-parameters/ssh-parameters.xhtml#ssh-parameters-18 for standard values."""

    first_kex_follows: Optional[bool] = None

    host_key_algorithms: OptionalNullable[List[str]] = UNSET
    r"""Asymmetric key algorithms for the host key supported by the client."""

    kex_algorithms: OptionalNullable[List[str]] = UNSET
    r"""Key exchange algorithms used in the handshake."""

    server_to_client_ciphers: OptionalNullable[List[str]] = UNSET
    r"""A list of ssh cipher algorithm identifiers, named according to section 6 of https://www.ietf.org/rfc/rfc4251.txt; see https://www.iana.org/assignments/ssh-parameters/ssh-parameters.xhtml#ssh-parameters-16 for standard values."""

    server_to_client_compression: OptionalNullable[List[str]] = UNSET
    r"""A list of ssh compression algorithm identifiers, named according to section 6 of https://www.ietf.org/rfc/rfc4251.txt; see https://www.iana.org/assignments/ssh-parameters/ssh-parameters.xhtml#ssh-parameters-20 for standard values."""

    server_to_client_languages: OptionalNullable[List[str]] = UNSET
    r"""A name-list of language tags in order of preference. As Defined in https://www.ietf.org/rfc/rfc3066.txt."""

    server_to_client_macs: OptionalNullable[List[str]] = UNSET
    r"""A list of ssh MAC algorithm identifiers, named according to section 6 of https://www.ietf.org/rfc/rfc4251.txt; see https://www.iana.org/assignments/ssh-parameters/ssh-parameters.xhtml#ssh-parameters-18 for standard values."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "client_to_server_ciphers",
            "client_to_server_compression",
            "client_to_server_languages",
            "client_to_server_macs",
            "first_kex_follows",
            "host_key_algorithms",
            "kex_algorithms",
            "server_to_client_ciphers",
            "server_to_client_compression",
            "server_to_client_languages",
            "server_to_client_macs",
        ]
        nullable_fields = [
            "client_to_server_ciphers",
            "client_to_server_compression",
            "client_to_server_languages",
            "client_to_server_macs",
            "host_key_algorithms",
            "kex_algorithms",
            "server_to_client_ciphers",
            "server_to_client_compression",
            "server_to_client_languages",
            "server_to_client_macs",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class QcStatementsMonetaryValueTypedDict(TypedDict):
    amount: NotRequired[int]
    currency: NotRequired[str]
    currency_number: NotRequired[int]
    exponent: NotRequired[int]


class QcStatementsMonetaryValue(BaseModel):
    amount: Optional[int] = None

    currency: Optional[str] = None

    currency_number: Optional[int] = None

    exponent: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .responseenvelopecollection import (
    ResponseEnvelopeCollection,
    ResponseEnvelopeCollectionTypedDict,
)
from censys_platform.types import BaseModel
from censys_platform.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V3CollectionsCrudGetGlobalsTypedDict(TypedDict):
    organization_id: NotRequired[str]


class V3CollectionsCrudGetGlobals(BaseModel):
    organization_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None


class V3CollectionsCrudGetRequestTypedDict(TypedDict):
    collection_uid: str
    r"""The UID for the collection. Obtain the collection ID using the [list collections endpoint](https://docs.censys.com/reference/v3-collections-crud-list#/) or via the collection URL when using the web console."""
    organization_id: NotRequired[str]
    r"""The ID of a Censys organization to associate the request with. See the [Getting Started docs](https://docs.censys.com/reference/get-started#step-3-find-and-use-your-organization-id-optional) for more information."""


class V3CollectionsCrudGetRequest(BaseModel):
    collection_uid: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The UID for the collection. Obtain the collection ID using the [list collections endpoint](https://docs.censys.com/reference/v3-collections-crud-list#/) or via the collection URL when using the web console."""

    organization_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""The ID of a Censys organization to associate the request with. See the [Getting Started docs](https://docs.censys.com/reference/get-started#step-3-find-and-use-your-organization-id-optional) for more information."""


class V3CollectionsCrudGetResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: ResponseEnvelopeCollectionTypedDict


class V3CollectionsCrudGetResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: ResponseEnvelopeCollection



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ElfFileTypedDict(TypedDict):
    class_: NotRequired[str]
    data: NotRequired[str]
    machine: NotRequired[str]
    os_abi: NotRequired[str]
    type: NotRequired[str]


class ElfFile(BaseModel):
    class_: Annotated[Optional[str], pydantic.Field(alias="class")] = None

    data: Optional[str] = None

    machine: Optional[str] = None

    os_abi: Optional[str] = None

    type: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class OpcUaLocalizedTextTypedDict(TypedDict):
    flags: NotRequired[int]
    locale: NotRequired[str]
    text: NotRequired[str]


class OpcUaLocalizedText(BaseModel):
    flags: Optional[int] = None

    locale: Optional[str] = None

    text: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from enum import Enum
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RejectType(str, Enum):
    UNKNOWN = ""
    WRONG_VERSION = "wrong_version"
    INVALID_USERNAME = "invalid_username"
    WRONG_USER_PW = "wrong_user_pw"
    WRONG_SERVER_PW = "wrong_server_pw"
    USERNAME_IN_USE = "username_in_use"
    SERVER_FULL = "server_full"
    NO_CERTIFICATE = "no_certificate"
    AUTHENTICATOR_FAIL = "authenticator_fail"


class RejectTypedDict(TypedDict):
    reason: NotRequired[str]
    type: NotRequired[RejectType]


class Reject(BaseModel):
    reason: Optional[str] = None

    type: Optional[RejectType] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class Ser2NetSerialParametersTypedDict(TypedDict):
    baud_rate: NotRequired[str]
    data_bits: NotRequired[str]
    parity: NotRequired[str]
    stop_bits: NotRequired[str]


class Ser2NetSerialParameters(BaseModel):
    baud_rate: Optional[str] = None

    data_bits: Optional[str] = None

    parity: Optional[str] = None

    stop_bits: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .http_repeatedheaders import HTTPRepeatedHeaders, HTTPRepeatedHeadersTypedDict
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class SsdpTypedDict(TypedDict):
    headers: NotRequired[Dict[str, HTTPRepeatedHeadersTypedDict]]
    upnp_url: NotRequired[str]


class Ssdp(BaseModel):
    headers: Optional[Dict[str, HTTPRepeatedHeaders]] = None

    upnp_url: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IppAttributeTypedDict(TypedDict):
    name: NotRequired[str]
    value_tag: NotRequired[int]


class IppAttribute(BaseModel):
    name: Optional[str] = None

    value_tag: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ActivemqTypedDict(TypedDict):
    cache_enabled: NotRequired[bool]
    cache_size: NotRequired[int]
    max_frame_size: NotRequired[int]
    max_inactivity_duration: NotRequired[int]
    max_inactivity_duration_initial_delay: NotRequired[int]
    platform_details: NotRequired[str]
    provider_name: NotRequired[str]
    provider_version: NotRequired[str]
    size_prefix_disabled: NotRequired[bool]
    stack_trace_enabled: NotRequired[bool]
    tcp_no_delay_enabled: NotRequired[bool]
    tight_encoding_enabled: NotRequired[bool]


class Activemq(BaseModel):
    cache_enabled: Optional[bool] = None

    cache_size: Optional[int] = None

    max_frame_size: Optional[int] = None

    max_inactivity_duration: Optional[int] = None

    max_inactivity_duration_initial_delay: Optional[int] = None

    platform_details: Optional[str] = None

    provider_name: Optional[str] = None

    provider_version: Optional[str] = None

    size_prefix_disabled: Optional[bool] = None

    stack_trace_enabled: Optional[bool] = None

    tcp_no_delay_enabled: Optional[bool] = None

    tight_encoding_enabled: Optional[bool] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class BasicConstraintsTypedDict(TypedDict):
    is_ca: NotRequired[bool]
    r"""Whether the certificate is permitted to sign other certificates."""
    max_path_len: NotRequired[int]
    r"""When present, provides the maximum number of intermediate certificates that may follow this certificate in a trusted certification path."""


class BasicConstraints(BaseModel):
    is_ca: Optional[bool] = None
    r"""Whether the certificate is permitted to sign other certificates."""

    max_path_len: Optional[int] = None
    r"""When present, provides the maximum number of intermediate certificates that may follow this certificate in a trusted certification path."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class UnrecognizedPublicKeyTypedDict(TypedDict):
    raw: NotRequired[str]


class UnrecognizedPublicKey(BaseModel):
    raw: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from datetime import datetime
from enum import Enum
from typing_extensions import TypedDict


class ChangeType(str, Enum):
    ADDED = "added"
    REMOVED = "removed"


class EventAssetChangeTypedDict(TypedDict):
    change_type: ChangeType
    event_time: datetime
    reason: str


class EventAssetChange(BaseModel):
    change_type: ChangeType

    event_time: datetime

    reason: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from censys_platform.utils import FieldMetadata, QueryParamMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GlobalsTypedDict(TypedDict):
    organization_id: NotRequired[str]


class Globals(BaseModel):
    organization_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class ModbusMEIResponseTypedDict(TypedDict):
    conformity_level: NotRequired[int]
    more_follows: NotRequired[bool]
    objects: NotRequired[Dict[str, str]]


class ModbusMEIResponse(BaseModel):
    conformity_level: Optional[int] = None

    more_follows: Optional[bool] = None

    objects: Optional[Dict[str, str]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pptp_responseinfo import PptpResponseInfo, PptpResponseInfoTypedDict
from .pptp_version import PptpVersion, PptpVersionTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PptpTypedDict(TypedDict):
    bearer_message: NotRequired[PptpResponseInfoTypedDict]
    error_message: NotRequired[PptpResponseInfoTypedDict]
    firmware: NotRequired[PptpVersionTypedDict]
    framing_message: NotRequired[PptpResponseInfoTypedDict]
    hostname: NotRequired[str]
    maximum_channels: NotRequired[int]
    protocol: NotRequired[PptpVersionTypedDict]
    result_message: NotRequired[PptpResponseInfoTypedDict]
    vendor: NotRequired[str]


class Pptp(BaseModel):
    bearer_message: Optional[PptpResponseInfo] = None

    error_message: Optional[PptpResponseInfo] = None

    firmware: Optional[PptpVersion] = None

    framing_message: Optional[PptpResponseInfo] = None

    hostname: Optional[str] = None

    maximum_channels: Optional[int] = None

    protocol: Optional[PptpVersion] = None

    result_message: Optional[PptpResponseInfo] = None

    vendor: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MongodbIsMasterTypedDict(TypedDict):
    is_master: NotRequired[bool]
    logical_session_timeout_minutes: NotRequired[int]
    max_bson_object_size: NotRequired[int]
    max_message_size_bytes: NotRequired[int]
    max_wire_version: NotRequired[int]
    max_write_batch_size: NotRequired[int]
    min_wire_version: NotRequired[int]
    read_only: NotRequired[bool]


class MongodbIsMaster(BaseModel):
    is_master: Optional[bool] = None

    logical_session_timeout_minutes: Optional[int] = None

    max_bson_object_size: Optional[int] = None

    max_message_size_bytes: Optional[int] = None

    max_wire_version: Optional[int] = None

    max_write_batch_size: Optional[int] = None

    min_wire_version: Optional[int] = None

    read_only: Optional[bool] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class RdateTypedDict(TypedDict):
    date_: NotRequired[str]


class Rdate(BaseModel):
    date_: Annotated[Optional[str], pydantic.Field(alias="date")] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EventsCapabilitiesTypedDict(TypedDict):
    max_notification_producers: NotRequired[int]
    max_pull_points: NotRequired[int]
    ws_pausable_subscription_manager_interface_support: NotRequired[bool]
    ws_pull_point_support: NotRequired[bool]
    ws_subscription_policy_support: NotRequired[bool]


class EventsCapabilities(BaseModel):
    max_notification_producers: Optional[int] = None

    max_pull_points: Optional[int] = None

    ws_pausable_subscription_manager_interface_support: Optional[bool] = None

    ws_pull_point_support: Optional[bool] = None

    ws_subscription_policy_support: Optional[bool] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ZLintTypedDict(TypedDict):
    errors_present: NotRequired[bool]
    r"""Whether the certificate's attributes triggered any error lints for non-conformance to the X.509 standard."""
    failed_lints: NotRequired[Nullable[List[str]]]
    r"""A list of lint names which failed, if applicable."""
    fatals_present: NotRequired[bool]
    r"""Whether the certificate's attributes triggered any fatal lints for non-conformance to the X.509 standard."""
    notices_present: NotRequired[bool]
    r"""Whether the certificate's attributes triggered any notice lints for non-conformance to the X.509 standard."""
    timestamp: NotRequired[str]
    r"""An RFC-3339-formated timestamp indicating when the certificate was linted."""
    version: NotRequired[int]
    r"""The version of Zlint used to lint the certificate."""
    warnings_present: NotRequired[bool]
    r"""Whether the certificate's attributes triggered any warning lints for non-conformance to the X.509 standard."""


class ZLint(BaseModel):
    errors_present: Optional[bool] = None
    r"""Whether the certificate's attributes triggered any error lints for non-conformance to the X.509 standard."""

    failed_lints: OptionalNullable[List[str]] = UNSET
    r"""A list of lint names which failed, if applicable."""

    fatals_present: Optional[bool] = None
    r"""Whether the certificate's attributes triggered any fatal lints for non-conformance to the X.509 standard."""

    notices_present: Optional[bool] = None
    r"""Whether the certificate's attributes triggered any notice lints for non-conformance to the X.509 standard."""

    timestamp: Optional[str] = None
    r"""An RFC-3339-formated timestamp indicating when the certificate was linted."""

    version: Optional[int] = None
    r"""The version of Zlint used to lint the certificate."""

    warnings_present: Optional[bool] = None
    r"""Whether the certificate's attributes triggered any warning lints for non-conformance to the X.509 standard."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "errors_present",
            "failed_lints",
            "fatals_present",
            "notices_present",
            "timestamp",
            "version",
            "warnings_present",
        ]
        nullable_fields = ["failed_lints"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ssh_algorithmselection_directionalgorithms import (
    SSHAlgorithmSelectionDirectionAlgorithms,
    SSHAlgorithmSelectionDirectionAlgorithmsTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SSHAlgorithmSelectionTypedDict(TypedDict):
    client_to_server_alg_group: NotRequired[
        SSHAlgorithmSelectionDirectionAlgorithmsTypedDict
    ]
    host_key_algorithm: NotRequired[str]
    kex_algorithm: NotRequired[str]
    server_to_client_alg_group: NotRequired[
        SSHAlgorithmSelectionDirectionAlgorithmsTypedDict
    ]


class SSHAlgorithmSelection(BaseModel):
    client_to_server_alg_group: Optional[SSHAlgorithmSelectionDirectionAlgorithms] = (
        None
    )

    host_key_algorithm: Optional[str] = None

    kex_algorithm: Optional[str] = None

    server_to_client_alg_group: Optional[SSHAlgorithmSelectionDirectionAlgorithms] = (
        None
    )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .mssql_preloginoptions_serverversion import (
    MssqlPreloginOptionsServerVersion,
    MssqlPreloginOptionsServerVersionTypedDict,
)
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class MssqlPreloginOptionsTypedDict(TypedDict):
    encrypt_mode: NotRequired[str]
    fed_auth_required: NotRequired[bool]
    instance: NotRequired[str]
    mars: NotRequired[bool]
    nonce: NotRequired[str]
    server_version: NotRequired[MssqlPreloginOptionsServerVersionTypedDict]
    thread_id: NotRequired[int]
    trace_id: NotRequired[str]
    unknown: NotRequired[Dict[str, str]]


class MssqlPreloginOptions(BaseModel):
    encrypt_mode: Optional[str] = None

    fed_auth_required: Optional[bool] = None

    instance: Optional[str] = None

    mars: Optional[bool] = None

    nonce: Optional[str] = None

    server_version: Optional[MssqlPreloginOptionsServerVersion] = None

    thread_id: Optional[int] = None

    trace_id: Optional[str] = None

    unknown: Optional[Dict[str, str]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .floatvalue import FloatValue, FloatValueTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ChromecastVolumeTypedDict(TypedDict):
    control_type: NotRequired[str]
    level: NotRequired[float]
    muted: NotRequired[bool]
    step_interval: NotRequired[FloatValueTypedDict]


class ChromecastVolume(BaseModel):
    control_type: Optional[str] = None

    level: Optional[float] = None

    muted: Optional[bool] = None

    step_interval: Optional[FloatValue] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel, Nullable, UNSET_SENTINEL
from enum import Enum
from pydantic import model_serializer
from typing import List
from typing_extensions import TypedDict


class Targets(str, Enum):
    HOST = "host"
    WEB = "web"
    CERT = "cert"
    UNKNOWN = "unknown"


class AlternativeQueryTypedDict(TypedDict):
    query: str
    r"""An alternative query that may be used."""
    targets: Nullable[List[Targets]]
    r"""The types of Platform data records (host, cert, and web) that can be targeted by the alternative query."""


class AlternativeQuery(BaseModel):
    query: str
    r"""An alternative query that may be used."""

    targets: Nullable[List[Targets]]
    r"""The types of Platform data records (host, cert, and web) that can be targeted by the alternative query."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["targets"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class GraphqlTypedDict(TypedDict):
    response: NotRequired[str]
    supports_introspection: NotRequired[bool]


class Graphql(BaseModel):
    response: Optional[str] = None

    supports_introspection: Optional[bool] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .networkcapabilities import NetworkCapabilities, NetworkCapabilitiesTypedDict
from .securitycapabilities import SecurityCapabilities, SecurityCapabilitiesTypedDict
from .systemcapabilities import SystemCapabilities, SystemCapabilitiesTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DeviceCapabilitiesTypedDict(TypedDict):
    network: NotRequired[NetworkCapabilitiesTypedDict]
    security: NotRequired[SecurityCapabilitiesTypedDict]
    system: NotRequired[SystemCapabilitiesTypedDict]


class DeviceCapabilities(BaseModel):
    network: Optional[NetworkCapabilities] = None

    security: Optional[SecurityCapabilities] = None

    system: Optional[SystemCapabilities] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Union
from typing_extensions import TypeAliasType, TypedDict


class HostnamePortTypedDict(TypedDict):
    hostname: str
    r"""Hostname to scan"""
    port: int
    r"""Port number to scan"""


class HostnamePort(BaseModel):
    hostname: str
    r"""Hostname to scan"""

    port: int
    r"""Port number to scan"""


class Target2TypedDict(TypedDict):
    r"""Discovery scan against hostname:PORT"""

    hostname_port: HostnamePortTypedDict


class Target2(BaseModel):
    r"""Discovery scan against hostname:PORT"""

    hostname_port: HostnamePort


class HostPortTypedDict(TypedDict):
    ip: str
    r"""IP address to scan"""
    port: int
    r"""Port number to scan"""


class HostPort(BaseModel):
    ip: str
    r"""IP address to scan"""

    port: int
    r"""Port number to scan"""


class Target1TypedDict(TypedDict):
    r"""Discovery scan against IP:PORT"""

    host_port: HostPortTypedDict


class Target1(BaseModel):
    r"""Discovery scan against IP:PORT"""

    host_port: HostPort


ScansDiscoveryInputBodyTargetTypedDict = TypeAliasType(
    "ScansDiscoveryInputBodyTargetTypedDict", Union[Target1TypedDict, Target2TypedDict]
)


ScansDiscoveryInputBodyTarget = TypeAliasType(
    "ScansDiscoveryInputBodyTarget", Union[Target1, Target2]
)


class ScansDiscoveryInputBodyTypedDict(TypedDict):
    target: ScansDiscoveryInputBodyTargetTypedDict


class ScansDiscoveryInputBody(BaseModel):
    target: ScansDiscoveryInputBodyTarget
